# Changelog

## [Unreleased][]

[Unreleased]: https://github.com/chaostoolkit/chaosplatform-scheduler/compare/0.1.1...HEAD

## [0.1.1][] - 2018-01-12

[0.1.1]: https://github.com/chaostoolkit/chaosplatform-scheduler/compare/0.1.0..0.1.1

### Changed

-  Pin only a minimum version of each dependency for composability

## [0.1.0][] - 2019-01-11

[0.1.0]: https://github.com/chaostoolkit/chaosplatform-scheduler/tree/0.1.0

### Added

-   Initial release